@@ -431,6 +431,17 @@ class Analytics:
         self.header['x-proxy-global-company-id'] = company_id
         self.endpoint_company = f"{self._endpoint}/{company_id}"
         self.company_id = company_id
+        try:
+            import importlib.resources as pkg_resources
+            pathLOGS = pkg_resources.path(
+                "aanalytics2", "eventType_usageLogs.pickle")
+        except ImportError:
+            # Try backported to PY<37 `importlib_resources`.
+            import pkg_resources
+            pathLOGS = pkg_resources.resource_filename(
+                "aanalytics2", "eventType_usageLogs.pickle")
+        with pathLOGS as f:
+            self.LOGS_EVENT_TYPE = pd.read_pickle(f)
 
     def refreshToken(self, token: str = None):
         if token is None:
@@ -1351,19 +1362,21 @@ class Analytics:
             df.to_csv('projects.csv', index=False)
         return df
 
-    def getProject(self, projectId: str = None, projectClass: bool = False, verbose: bool = False) -> dict:
+    def getProject(self, projectId: str = None, projectClass: bool = False, retry: int = 0,verbose: bool = False) -> dict:
         """
         Return the dictionary of the project information and its definition.
         Arguments:
             projectId : REQUIRED : the project ID to be retrieved.
             projectClass : OPTIONAL : if set to True. Returns a class of the project with prefiltered information
+            retry : OPTIONAL : If you want to retry the request if it fails. Specify number of retry (0 default)
+            verbose : OPTIONAL : If you wish to have logs of status
         """
         if projectId is None:
             raise Exception("Requires a projectId parameter")
         params = {
             'expansion': 'definition,ownerFullName,modified,favorite,approved,tags,shares,sharesFullName,reportSuiteName,companyTemplate,accessLevel'}
         path = f"/projects/{projectId}"
-        res = self.connector.getData(self.endpoint_company + path, params=params, headers=self.header, verbose=verbose)
+        res = self.connector.getData(self.endpoint_company + path, params=params, headers=self.header,retry=retry, verbose=verbose)
         if projectClass:
             if verbose:
                 print('building an instance of Project class')
@@ -1439,6 +1452,79 @@ class Analytics:
             raise ValueError("Requires definition key to be a dictionary")
         res = self.connector.postData(self.endpoint_company + path, data=projectObj, headers=self.header)
         return res
+    
+    def getUsageLogs(self,
+        startDate:str=None,
+        endDate:str=None,
+        eventType:str=None,
+        event:str=None,
+        rsid:str=None,
+        login:str=None,
+        ip:str=None,
+        limit:int=100,
+        max_result:int=None,
+        format:str="df",
+        verbose:bool=False,
+        **kwargs)->dict:
+        """
+        Returns the Audit Usage Logs from your company analytics setup.
+        Arguments:
+            startDate : REQUIRED : Start date, format : 2020-12-01T00:00:00-07.(default 3 month prior today)	
+            endDate : REQUIRED : End date, format : 2020-12-15T14:32:33-07. (default today)
+                Should be a maximum of a 3 month period between startDate and endDate.
+            eventType : OPTIONAL : The numeric id for the event type you want to filter logs by. 
+                Please reference the lookup table in the LOGS_EVENT_TYPE
+            event : OPTIONAL : The event description you want to filter logs by. 
+                No wildcards are permitted, but this filter is case insensitive and supports partial matches.
+            rsid : OPTIONAL : ReportSuite ID to filter on.
+            login : OPTIONAL : The login value of the user you want to filter logs by. This filter functions as an exact match.	
+            ip : OPTIONAL : The IP address you want to filter logs by. This filter supports a partial match.	
+            limit : OPTIONAL : Number of results per page.
+            max_result : OPTIONAL : Number of maximum amount of results if you want. If you want to cap the process. Ex : max_result=1000
+            format : OPTIONAL : If you wish to have a DataFrame ("df" - default) or list("raw") as output.
+            verbose : OPTIONAL : Set it to True if you want to have console info.
+        possible kwargs:
+            page : page number (default 0)
+        """
+        import datetime
+        now =  datetime.datetime.now()
+        if startDate is None:
+            startDate = datetime.datetime.isoformat(now - datetime.timedelta(weeks=4*3)).split('.')[0]
+        if endDate is None:
+            endDate = datetime.datetime.isoformat(now).split('.')[0]
+        path = "/auditlogs/usage"
+        params = {"page":kwargs.get('page',0),"limit":limit,"startDate":startDate,"endDate":endDate}
+        if eventType is not None:
+            params['eventType'] = eventType
+        if event is not None:
+            params['event'] = event
+        if rsid is not None:
+            params['rsid'] = rsid
+        if login is not None:
+            params['login'] = login
+        if ip is not None:
+            params['ip'] = ip
+        if verbose:
+            print("retrieving data with these parameters")
+            print(json.dumps(params,indent=2))
+        res = self.connector.getData(self.endpoint_company + path, params=params,verbose=verbose)
+        data = res['content']
+        lastPage = res['lastPage']
+        while lastPage == False:
+            params["page"] += 1
+            print(f"fetching page{params['page']}")
+            res = self.connector.getData(self.endpoint_company + path, params=params,verbose=verbose)
+            data += res['content']
+            lastPage = res['lastPage']
+            if max_result is not None:
+                if len(data) >= max_result:
+                    lastPage = True
+        if format == "df":
+            df = pd.DataFrame(data)
+            return df
+        return data
+
+
 
     def _dataDescriptor(self, json_request: dict):
         """
@@ -1522,6 +1608,7 @@ class Analytics:
             n_result: Union[int, str] = 1000,
             save: bool = False,
             item_id: bool = False,
+            unsafe: bool = False,
             verbose: bool = False,
             debug=False
     ) -> object:
@@ -1537,9 +1624,14 @@ class Analytics:
             n_result : OPTIONAL : Number of result that you would like to retrieve. (default 1000)
                 if you want to have all possible data, use "inf".
             item_id : OPTIONAL : Boolean to define if you want to return the item id for sub requests (default False)
+            unsafe : OPTIONAL : If set to True, it will not check "lastPage" parameter and assume first request is complete. 
+                This may break the script or return incomplete data. (default False).
             save : OPTIONAL : If you would like to save the data within a CSV file. (default False)
             verbose : OPTIONAL : If you want to have comment display (default False)
+            
         """
+        if unsafe and verbose:
+            print('---- running the getReport in "unsafe" mode ----')
         obj = {}
         if type(json_request) == str and '.json' not in json_request:
             try:
@@ -1591,10 +1683,11 @@ class Analytics:
                 time.sleep(50)
                 report = self.connector.postData(self.endpoint_company +
                                              self._getReport, data=request, headers=self.header)
-            if 'lastPage' not in report:  # checking error when no lastPage key in report
+            if 'lastPage' not in report and unsafe == False:  # checking error when no lastPage key in report
                 if verbose:
                     print(json.dumps(report, indent=2))
-                print('Warning : Server Error - no save file & empty dataframe.')
+                print('Warning : Server Error')
+                print(json.dumps(report))
                 if debug:
                     with open(f'server_failure_request_{timestamp}.json', 'w') as f:
                         f.write(json.dumps(request, indent=4))
